@@ -24,6 +24,10 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <unistd.h>		/* for STDIN_FILENO */
+#include <sys/types.h>		/* for open */
+#include <sys/stat.h>		/* for open */
+#include <fcntl.h>		/* for open */
 #include <signal.h>
 #include <errno.h>
 #include <X11/keysym.h>
@@ -782,6 +786,10 @@ void CMD_Exec(F_CMD_ARGS)
   /* Not everyone has vfork! */
   if (!(fork())) /* child process */
   {
+    /* This is for fixing a problem with rox filer */
+    int fd;
+    fd = open("/dev/null", O_RDONLY, 0);
+    dup2(fd,STDIN_FILENO);
     if (execl(exec_shell_name, exec_shell_name, "-c", cmd, NULL)==-1)
     {
       fvwm_msg(ERR,"exec_function","execl failed (%s)",strerror(errno));
@@ -2595,20 +2603,19 @@ void CMD_SetEnv(F_CMD_ARGS)
   char *szValue = NULL;
   char *szPutenv = NULL;
 
-  action = GetNextToken(action,&szVar);
+  action = GetNextToken(action, &szVar);
   if (!szVar)
     return;
-  action = GetNextToken(action,&szValue);
+  action = GetNextToken(action, &szValue);
   if (!szValue)
   {
-    /* no value, treat as unset */
-    CMD_UnsetEnv(F_PASS_ARGS);
+    /* no value, ignore */
     free(szVar);
     return;
   }
 
-  szPutenv = safemalloc(strlen(szVar)+strlen(szValue)+2);
-  sprintf(szPutenv,"%s=%s",szVar,szValue);
+  szPutenv = safemalloc(strlen(szVar) + strlen(szValue) + 2);
+  sprintf(szPutenv,"%s=%s", szVar, szValue);
   putenv(szPutenv);
   add_to_env_list(szVar, szPutenv);
   /* szVar is stored in the env list. do not free it */
@@ -2620,7 +2627,7 @@ void CMD_UnsetEnv(F_CMD_ARGS)
   char *szVar = NULL;
   char *szPutenv = NULL;
 
-  action = GetNextToken(action,&szVar);
+  action = GetNextToken(action, &szVar);
   if (!szVar)
     return;
 
